@@ -1,18 +1,15 @@
-import os
-from subprocess import call, PIPE
+from subprocess import Popen, PIPE
 
 from django.conf import settings as djangosettings
+from django.core.exceptions import ImproperlyConfigured
 
 
 def _is_installed(cmd):
-    there_is = False
-    cmd = [cmd, '--version']
     try:
-        call(cmd, stdout=PIPE)
-        there_is = True
-    except OSError as e:
-        pass
-    return there_is
+        resp = Popen(['which', cmd], stdout=PIPE)
+    except OSError:
+        return False
+    return resp.stdout.read().strip().endswith(cmd)
 
 
 class Settings():
@@ -47,4 +44,12 @@ class Settings():
     def JSLINT_IS_INSTALLED(self):
         return _is_installed(self.JSLINT_CMD)
 
+    @property
+    def SIGNAL_MODULES(self):
+        modules = getattr(self.conf, 'DJANGOMASTER_SIGNAL_MODULES', ())
+        if type(modules) not in (tuple, list):
+            raise ImproperlyConfigured('DJANGOMASTER_SIGNAL_MODULES must be '
+                                       'a tuple')
+        return modules
+
 settings = Settings()
