@@ -3,11 +3,16 @@ import djangomaster
 from django.conf import settings
 from django.conf.urls import patterns, url, include
 from django.conf.urls.static import static
+from django.contrib import admin
+
+
+admin.autodiscover()
 
 
 urlpatterns = patterns(
     r'',
 
+    url(r'^admin/', include(admin.site.urls)),
     url(r'^master/', include(djangomaster.urls)),
 
 )
